@@ -101,6 +101,9 @@ INTERNALERROR_GETRIGHTFAILED = 'InternalError.GetRightFailed'
 # Failed to query security group details.
 INTERNALERROR_GETSECURITYGROUPDETAILFAILED = 'InternalError.GetSecurityGroupDetailFailed'
 
+# Failed to query slow query logs.
+INTERNALERROR_GETSLOWLOGFAILED = 'InternalError.GetSlowLogFailed'
+
 # Failed to query the VPC subnet information.
 INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
 
@@ -173,6 +176,9 @@ INVALIDPARAMETER_GENERICPARAMETERERROR = 'InvalidParameter.GenericParameterError
 # Invalid parameters.
 INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError'
 
+# Incorrect time parameter.
+INVALIDPARAMETER_ILLEGALTIME = 'InvalidParameter.IllegalTime'
+
 # Failed to find the requested instance.
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
