@@ -29,6 +29,8 @@ class EcdnClient(AbstractClient):
     def AddEcdnDomain(self, request):
         """This API is used to create an acceleration domain name.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/41123?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for AddEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.AddEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.AddEcdnDomainResponse`
@@ -57,6 +59,8 @@ class EcdnClient(AbstractClient):
     def DeleteEcdnDomain(self, request):
         """This API is used to delete a specified acceleration domain name. The acceleration domain name to be deleted must be in disabled status.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/570/42471?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for DeleteEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DeleteEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DeleteEcdnDomainResponse`
@@ -85,6 +89,8 @@ class EcdnClient(AbstractClient):
     def DescribeDomains(self, request):
         """This API is used to query the basic information of a CDN domain name, including the project ID, status, business type, creation time, update time, etc.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/41118?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for DescribeDomains.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsResponse`
@@ -113,6 +119,8 @@ class EcdnClient(AbstractClient):
     def DescribeDomainsConfig(self, request):
         """This API is used to query the detailed configuration information of a CDN acceleration domain name.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/41117?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for DescribeDomainsConfig.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsConfigRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsConfigResponse`
@@ -231,7 +239,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeIpStatus(self, request):
-        """This API is used to query the detailed node information of the acceleration platform to which the domain name is connected.
+        """This API is used to query ECDN node IPs. This API is only available to beta users. Please submit a ticket to use it.
+
+        If you need to add the node IPs to your origin allowlist, keep querying the updating the IPs regularly to ensure the success of origin forwarding.
 
         :param request: Request instance for DescribeIpStatus.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeIpStatusRequest`
@@ -261,6 +271,8 @@ class EcdnClient(AbstractClient):
     def DescribePurgeQuota(self, request):
         """This API is used to query the usage quota of the purge API.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/41956?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for DescribePurgeQuota.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeQuotaRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeQuotaResponse`
@@ -287,7 +299,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribePurgeTasks(self, request):
-        """This API is used to query the submission history of purge tasks and their execution progress.
+        """This API is used to query the submission record and progress of purge tasks.
+
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/37873?from_cn_redirect=1">corresponding CDN API</a>.
 
         :param request: Request instance for DescribePurgeTasks.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeTasksRequest`
@@ -317,6 +331,8 @@ class EcdnClient(AbstractClient):
     def PurgePathCache(self, request):
         """This API is used to purge cache directories in batches. One purge task ID will be returned for each submission.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/570/42475?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for PurgePathCache.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.PurgePathCacheRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.PurgePathCacheResponse`
@@ -345,6 +361,8 @@ class EcdnClient(AbstractClient):
     def PurgeUrlsCache(self, request):
         """This API is used to batch purge URLs. One purge task ID will be returned for each submission.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/api/228/37870?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for PurgeUrlsCache.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheResponse`
@@ -373,6 +391,8 @@ class EcdnClient(AbstractClient):
     def StartEcdnDomain(self, request):
         """This API is used to enable an acceleration domain name. The domain name to be enabled must be in deactivated status.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/product/228/41121?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for StartEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.StartEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.StartEcdnDomainResponse`
@@ -401,6 +421,8 @@ class EcdnClient(AbstractClient):
     def StopEcdnDomain(self, request):
         """This API is used to disable an acceleration domain name. The domain name to be disabled must be in enabled or deploying status.
 
+        >? If you have migrated your ECDN service to CDN, you can use the <a href="https://intl.cloud.tencent.com/document/product/228/41120?from_cn_redirect=1">corresponding CDN API</a>.
+
         :param request: Request instance for StopEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.StopEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.StopEcdnDomainResponse`
@@ -428,7 +450,9 @@ class EcdnClient(AbstractClient):
 
     def UpdateDomainConfig(self, request):
         """This API is used to update the configuration information of an ECDN acceleration domain name.
-        Note: if you need to update a complex configuration item, you must pass in all attributes of the entire object, and the default values will be used for the attributes that are not passed in. You are recommended to get the configuration attribute through the query API first and then directly modify and pass it to this API. Due to the special nature of the certificate for HTTPS configuration, you do not need to pass in the certificate and key fields during the update.
+        Note: if you need to update complex configuration items, you must pass all the attributes of the entire object. The default value will be used for attributes that are not passed. We recommend calling the querying API to obtain the configuration attributes first. You can then modify and pass the attributes to the API. The certificate and key fields do not need to be passed for HTTPS configuration.
+
+        >?  If your application has been migrated to Tencent Cloud CDN, you can use <a href="https://intl.cloud.tencent.com/document/product/228/41116?from_cn_redirect=1">CDN APIs</a>.
 
         :param request: Request instance for UpdateDomainConfig.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.UpdateDomainConfigRequest`
