@@ -86,6 +86,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # Incorrect display policy.
 INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'
 
+# Parameter error.
+INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'
+
 # The number of common nodes is invalid.
 INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 
@@ -134,6 +137,9 @@ INVALIDPARAMETER_INVALIDEXTENDFIELD = 'InvalidParameter.InvalidExtendField'
 # Invalid cluster name.
 INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 
+# Invalid model.
+INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'
+
 # Invalid login settings.
 INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'
 
