@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# Invalid key.
+AUTHFAILURE_ACCESSKEYILLEGAL = 'AuthFailure.AccessKeyIllegal'
+
 # Database error.
 INTERNALERROR_DBERROR = 'InternalError.DbError'
 
@@ -26,7 +29,7 @@ INTERNALERROR_GETAPPIDERROR = 'InternalError.GetAppIdError'
 # Failed to get the role.
 INTERNALERROR_GETROLEERROR = 'InternalError.GetRoleError'
 
-# Failed to obtain the seed token.
+# Failed to obtain the token.
 INTERNALERROR_GETSEEDTOKENERROR = 'InternalError.GetSeedTokenError'
 
 # Invalid role.
@@ -35,12 +38,15 @@ INTERNALERROR_ILLEGALROLE = 'InternalError.IllegalRole'
 # pb packaging failed.
 INTERNALERROR_PBSERIALIZEERROR = 'InternalError.PbSerializeError'
 
-# Internal error.
+# Internal system error, such as network error.
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
 # Unknown error.
 INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
 
+# This type of key is not supported.
+INVALIDPARAMETER_ACCESSKEYNOTSUPPORT = 'InvalidParameter.AccessKeyNotSupport'
+
 # The account does not exist or is unavailable.
 INVALIDPARAMETER_ACCOUNTNOTAVALIABLE = 'InvalidParameter.AccountNotAvaliable'
 
@@ -62,7 +68,7 @@ INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 # The policy is too long.
 INVALIDPARAMETER_POLICYTOOLONG = 'InvalidParameter.PolicyTooLong'
 
-# Resource error.
+# Six-segment resource description error.
 INVALIDPARAMETER_RESOUCEERROR = 'InvalidParameter.ResouceError'
 
 # Policy syntax error.
@@ -71,7 +77,7 @@ INVALIDPARAMETER_STRATEGYFORMATERROR = 'InvalidParameter.StrategyFormatError'
 # Invalid policy.
 INVALIDPARAMETER_STRATEGYINVALID = 'InvalidParameter.StrategyInvalid'
 
-# Invalid `TCB temp code`.
+# Invalid temporary code.
 INVALIDPARAMETER_TEMPCODENOTAVALIABLE = 'InvalidParameter.TempCodeNotAvaliable'
 
 # The role corresponding to the account does not exist.
