@@ -1062,6 +1062,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeClusterStatus(self, request):
+        """This API is used to query the information of clusters under the current account.
+
+        :param request: Request instance for DescribeClusterStatus.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeClusterStatusRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeClusterStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeClusterStatus", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClusterStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusters(self, request):
         """This API is used to query clusters list.
 
